@@ -4,8 +4,10 @@
 
 import sys
 import argparse
+import shutil
 import structlog
 import json
+import os.path
 
 from . import core
 
@@ -39,6 +41,9 @@ def take() -> None:
   oldvers = core.read_verfile(oldverf)
   newvers = core.read_verfile(newverf)
 
+  for removed in set(oldvers) - set(newvers):
+    del oldvers[removed]
+
   if args.all:
     oldvers.update(newvers)
   else:
@@ -60,9 +65,12 @@ def take() -> None:
           sys.exit(2)
 
   try:
-    oldverf.rename(
-      oldverf.with_name(oldverf.name + '~'),
-    )
+    if os.path.islink(oldverf):
+      shutil.copy(oldverf, oldverf.with_name(oldverf.name + '~'))
+    else:
+      oldverf.rename(
+        oldverf.with_name(oldverf.name + '~'),
+      )
   except FileNotFoundError:
     pass
   core.write_verfile(oldverf, oldvers)
@@ -78,11 +86,14 @@ def cmp() -> None:
   parser.add_argument('-a', '--all', action='store_true',
                       help="Include unchanged versions.")
   parser.add_argument('-s', '--sort',
-                      choices=('parse_version', 'vercmp', 'none'), default='parse_version',
+                      choices=('parse_version', 'vercmp', 'awesomeversion', 'none'),
+                      default='parse_version',
                       help='Version compare method to backwards the arrow '
                            '(default: parse_version)')
   parser.add_argument('-n', '--newer', action='store_true',
                       help='Shows only the newer ones according to --sort.')
+  parser.add_argument('--exit-status', action='store_true',
+                      help="exit with status 4 if there are updates")
   args = parser.parse_args()
   if core.process_common_arguments(args):
     return
@@ -123,7 +134,7 @@ def cmp() -> None:
         from .sortversion import sort_version_keys
         version = sort_version_keys[args.sort]
 
-        if version(oldver) > version(newver):  # type: ignore
+        if version(oldver) > version(newver): # type: ignore
           if args.newer:
             continue  # don't store this diff
           diff['delta'] = 'old'
@@ -182,3 +193,8 @@ def cmp() -> None:
       style = diffstyles[diff.get('delta', 'equal')] # type: ignore # mypy has issues with this line
 
       print(f'{diff["name"]} {style["oldc"]}{diff["oldver"]}{c.normal} {style["symbol"]} {c.green}{diff["newver"]}{c.normal}')
+
+  if args.exit_status and any(
+    diff.get('delta') != 'equal' for diff in differences
+  ):
+    sys.exit(4)
